;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "helm-raindrop" "20250806.1220"
  "Raindrop.io with helm interface."
  '((emacs   "29.1")
    (helm    "4.0.4")
    (request "0.3.2"))
  :url "https://github.com/masutaka/emacs-helm-raindrop"
  :commit "6c080b1acf51ada473a7252cca7e0a5d812be4b0"
  :revdesc "6c080b1acf51"
  :authors '(("Takashi Masuda" . "masutaka.net@gmail.com"))
  :maintainers '(("Takashi Masuda" . "masutaka.net@gmail.com")))
